@@ -1,21 +1,9 @@
 /*
-  Copyright (c) 2008 Bruno Virlet <bvirlet@kdemail.net>
-                2009 KDAB; Author: Frank Osterfeld <osterfeld@kde.org>
+  SPDX-FileCopyrightText: 2008 Bruno Virlet <bvirlet@kdemail.net>
+  SPDX-FileCopyrightText: 2009 KDAB
+  SPDX-FileContributor: Frank Osterfeld <osterfeld@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "calendarmodel_p.h"
@@ -23,9 +11,9 @@
 #include "utils_p.h"
 #include <monitor.h>
 #include <itemfetchscope.h>
-#include <kcalendarcore/event.h>
+#include <KCalendarCore/Event>
 #include <kcalendarcore/todo.h>
-#include <kcalendarcore/journal.h>
+#include <KCalendarCore/Journal>
 
 #include <KLocalizedString>
 
